package com.wd.workoffice.ui.activity.mes.ticket;

import android.text.TextUtils;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;

import com.alibaba.fastjson.JSON;
import com.chad.library.adapter.base.BaseQuickAdapter;
import com.scwang.smartrefresh.layout.SmartRefreshLayout;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseMesBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.listener.FourMenuClickListener;
import com.wd.workoffice.bean.mesBean.TicketBean;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.adapter.MesTicketAdapter;
import com.wd.workoffice.util.WorkUtils;
import com.wd.workoffice.util.ddmfilter.MesTicketListFilterData;
import com.wd.workoffice.widget.DropDownMenu;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.disposables.Disposable;


/**
 * 担当列表
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class MesTicketListTakeOnActivity extends WorkToolBarActivity {

    @BindView(R.id.ddm_choose)
    DropDownMenu ddmChoose;
    private RecyclerView rvData;
    private int page = 1;
    private Map<String, Object> param;
    private SmartRefreshLayout srlRefresh;
    private List<TicketBean.ListBean> dataList;
    private MesTicketAdapter dataAdapter;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        MesTicketListFilterData filterData = new MesTicketListFilterData(this, ddmChoose, new FourMenuClickListener() {
            @Override
            public void clickOne(String value) {
                if (TextUtils.equals(value, "全部状态")) {
                    param.put("level", "");
                } else if (TextUtils.equals(value, "一级库")) {
                    param.put("level", "1");
                } else {
                    param.put("level", "2");
                }
                page = 1;
                param.put("pageNum", page);
                getData();
            }

            @Override
            public void clickTwo(String value) {
                if (TextUtils.equals(value, "全部类型")) {
                    param.put("type", "");
                } else if (TextUtils.equals(value, "厂内库")) {
                    param.put("type", "IN");
                } else {
                    param.put("type", "OUT");
                }
                page = 1;
                param.put("page", page);
                getData();
            }

            @Override
            public void clickThree(String value) {
                if (TextUtils.equals(value, "全部状态")) {
                    param.put("status", "");
                } else if (TextUtils.equals(value, "未启用")) {
                    param.put("status", "0");
                } else {
                    param.put("status", "1");
                }
                page = 1;
                param.put("pageNum", page);
                getData();
            }

            @Override
            public void clickFour(String value) {

            }
        });
        rvData = filterData.getRvData();
        srlRefresh = filterData.getSrlRefresh();
    }


    @Override
    protected void initData() {
        dataList = new ArrayList<>();
        dataAdapter = new MesTicketAdapter(R.layout.item_mes_ticket, dataList);
        dataAdapter.bindToRecyclerView(rvData);
        dataAdapter.setEmptyView(R.layout.view_empty_content, rvData);
        param = WorkUtils.pageMesKey();
        param.put("pageNum", page);
        getData();
    }

    private void getData() {
        RtfUtils.getMesRtf().ticketList("1",WorkUtils.convertMapToBody(param)).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseMesBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseMesBean data) {
                hideLoading();
                if (!data.isSuccess()) {
                    toast(data.getMessage());
                    return;
                }
                List<TicketBean.ListBean> getList = JSON.parseObject(data.getData().toString(), TicketBean.class).getList();
                if (page == 1) {
                    srlRefresh.finishRefresh();
                    dataList.clear();
                    dataList.addAll(getList);
                    dataAdapter.notifyDataSetChanged();
                    dataAdapter.loadMoreComplete();
                } else {
                    dataAdapter.loadMoreComplete();
                    dataList.addAll(getList);
                    dataAdapter.notifyDataSetChanged();
                }
                if (getList.size() == 0) {
                    dataAdapter.loadMoreEnd();
                } else {
                    page++;
                }
            }
        });
    }

    @Override
    protected void initEvent() {
        srlRefresh.setOnRefreshListener(refreshLayout -> {
            page = 1;
            param.put("pageNum", page);
            getData();
        });
        dataAdapter.setOnLoadMoreListener(() -> {
            param.put("pageNum", page);
            getData();
        }, rvData);
        dataAdapter.setOnItemClickListener(new BaseQuickAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(BaseQuickAdapter adapter, View view, int position) {
                startActivity(MesTicketDetailActivity.class, "from", "1");
            }
        });
    }


    @Override
    protected int layoutId() {
        return R.layout.activity_mes_ticket_list;
    }

    @OnClick(R.id.fab_go)
    public void onViewClicked() {
        startActivity(MesTicketListActivity.class);
        finish();
    }

}
